import { IExternalTask } from './iexternal_task';
/**
 * Describes an ExternalTask that the ProcessEngine has delegated to an
 * ExternalTask worker for processing.
 */
export declare class ExternalTask implements IExternalTask {
    private readonly _id;
    private readonly _workerId;
    private readonly _topic;
    private readonly _flowNodeInstanceId;
    private readonly _correlationId;
    private readonly _processInstanceId;
    private readonly _payload;
    private readonly _lockExpirationTime;
    private readonly _finished;
    private readonly _finishedAt;
    private readonly _result;
    private readonly _error;
    private readonly _createdAt;
    constructor(id: string, workerId: string, topic: string, flowNodeInstanceId: string, correlationId: string, processInstanceId: string, payload: any, lockExpirationTime: Date, finished: boolean, finishedAt?: Date, error?: Error, result?: any, createdAt?: Date);
    /**
     * The external tasks ID.
     */
    readonly id: string;
    /**
     * The ID of the worker that has most recently locked the ExternalTask
     * for processing.
     */
    readonly workerId: string;
    /**
     * The topic to which the ExternalTask belongs.
     */
    readonly topic: string;
    /**
     * The ID of the FlowNodeInstance that contains the definition
     * for the ExternalTask.
     */
    readonly flowNodeInstanceId: string;
    /**
     * The ID of the Correlation that contains the FlowNodeInstance with the
     * ExternalTask's definition.
     */
    readonly correlationId: string;
    /**
     * The ID of the ProcessInstance that contains the FlowNodeInstance with the
     * ExternalTask's definition.
     */
    readonly processInstanceId: string;
    /**
     * The lock expiration time. On expiration, the task is released to
     * be processed by other workers.
     * If not set, the ExternalTask is not locked.
     */
    readonly lockExpirationTime: Date;
    /**
     * The payload containing all relevant data the worker needs to execute the
     * ExternalTask.
     */
    readonly payload: any;
    /**
     * Determines if the ExternalTask as already been finished.
     */
    readonly isFinished: boolean;
    /**
     * The date and time at which the ExternalTask was finished.
     * Only set, if 'isFinished' is 'true'.
     */
    readonly finishedAt: Date;
    /**
     * If the ExternalTask was finished successfully, this will contain the result.
     */
    readonly result: boolean;
    /**
     * If the ExternalTask was finished with an error, this will contain the error.
     */
    readonly error: any;
    /**
     * The date and time at which the ExternalTask was created.
     */
    readonly createdAt: Date;
    /**
     * Determines whether the ExternalTask is currently locked or not.
     * A finished ExternalTask is always locked.
     */
    readonly isLocked: boolean;
}
